﻿using System;
using System.Collections.Generic;
using System.Text;

namespace Střelci
{
	/// <summary>
	/// Představuje počítačového hráče.
	/// </summary>
	public static class ComputerPlayer
	{
		/// <summary>
		/// Najde nejlepší tah pro hráče v dané partii.
		/// </summary>
		/// <param name="game">Partie, ve které se má tah odehrát.</param>
		/// <param name="playerColor">Hráč, který provede tah.</param>
		public static Move FindBestMove(Game game, Player player)
		{
			// vyresetujeme pocitadlo
			ThinkingCounter.Instance.Reset();

			return Minimax.FindBest(game, player.Color, player.ThinkingDepth);
		}

		/// <summary>
		/// Vrátí hodnotu určující, zda protihráči nabídnout remízu.
		/// </summary>
		/// <param name="game">Partie, která se nyní odehrává.</param>
		/// <param name="playerColor">Barva hráče, který by remízu nabízel.</param>
		public static bool ShouldOfferDraw(Game game, PieceColor playerColor)
		{
			int pocet_nasich = game.Chessboard.GetPlayerPieces(playerColor).Length;

			// pokud mame jenom krale, nabidneme
			if(pocet_nasich == 1)
				return true;

			// pokud ma protihrac 3x vic figurek, zbabele nabidneme
			int pocet_jeho = game.Chessboard.GetPlayerPieces(Player.ContraryColor(playerColor)).Length;
			if(3 * pocet_nasich <= pocet_jeho)
				return true;

			return false;
		}
	}
}
