﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using System.Diagnostics;

namespace Střelci
{
	/// <summary>
	/// Okno umožňující změnu hráčů.
	/// </summary>
	public partial class ChangePlayersForm : Form
	{
		private PlayerType _WhiteOriginalType;
		private PlayerType _BlackOriginalType;

		/// <summary>
		/// Vytvoří nové okno umožňující změnu hráčů.
		/// </summary>
		/// <param name="whitePlayer">Bílý hráč.</param>
		/// <param name="blackPlayer">Černý hráč.</param>
		public ChangePlayersForm(Player whitePlayer, Player blackPlayer)
		{
			InitializeComponent();

			Debug.Assert(Enum.GetValues(typeof(PlayerType)).Length == 2, "ChangePlayersForm je napsán pro dva druhy hráčů.");

			_WhiteOriginalType = whitePlayer.Type;
			_BlackOriginalType = blackPlayer.Type;

			// podle zadani sestavime popisky zatrzitek
			whiteChangeCheckBox.Text = GetCheckboxCaption(_WhiteOriginalType);
			blackChangeCheckBox.Text = GetCheckboxCaption(_BlackOriginalType);
			// a hloubky
			whiteTrackBar.Value = whitePlayer.ThinkingDepth;
			blackTrackBar.Value = blackPlayer.ThinkingDepth;

			// vychozi nastaveni
			playerType_CheckedChanged(this, EventArgs.Empty);
		}

		/// <summary>
		/// Vrátí odpovídající popisku zatržíka.
		/// </summary>
		private string GetCheckboxCaption(PlayerType originalPlayerType)
		{
			if(originalPlayerType == PlayerType.Human)
				return "Změnit na počítačového hráče a nechat ho hrát.";
			else
				return "Změnit na člověka a hrát dál sám.";
		}

		/// <summary>
		/// Vrátí druhý typ hráče, než je ten zadaný.
		/// </summary>
		protected PlayerType GetOtherType(PlayerType playerType)
		{
			return playerType == PlayerType.Human ? PlayerType.Computer : PlayerType.Human;
		}

		/// <summary>
		/// Vrátí druh bílého hráče.
		/// </summary>
		public PlayerType WhitePlayerType
		{
			get { return whiteChangeCheckBox.Checked ? GetOtherType(_WhiteOriginalType) : _WhiteOriginalType; }
			set	{ whiteChangeCheckBox.Checked = _WhiteOriginalType != value; }
		}

		/// <summary>
		/// Vrátí true, pokud uživatel změnil druh bílého hráče.
		/// </summary>
		public bool WhitePlayerTypeChanged
		{
			get { return whiteChangeCheckBox.Checked; }
		}

		/// <summary>
		/// Vrátí druh černého hráče.
		/// </summary>
		public PlayerType BlackPlayerType
		{
			get { return blackChangeCheckBox.Checked ? GetOtherType(_BlackOriginalType) : _BlackOriginalType; }
			set { blackChangeCheckBox.Checked = _BlackOriginalType != value; }
		}

		/// <summary>
		/// Vrátí true, pokud uživatel změnil druh černého hráče.
		/// </summary>
		public bool BlackPlayerTypeChanged
		{
			get { return blackChangeCheckBox.Checked; }
		}

		/// <summary>
		/// Vrátí hloubku přemýšlení bílého hráče.
		/// </summary>
		public int WhitePlayerDepth
		{
			get { return whiteTrackBar.Value; }
		}

		/// <summary>
		/// Vrátí hloubku přemýšlení černého hráče.
		/// </summary>
		public int BlackPlayerDepth
		{
			get { return blackTrackBar.Value; }
		}

		private void playerType_CheckedChanged(object sender, EventArgs e)
		{
			// povolime/zakazeme soupatka
			whiteTrackBar.Enabled = WhitePlayerType == PlayerType.Computer;
			blackTrackBar.Enabled = BlackPlayerType == PlayerType.Computer;
		}
	}
}