using System;
using System.Diagnostics;

namespace Stelci
{
	partial class ChessForm
	{
		void _CurrentGame_DrawOffersChanged(object sender, EventArgs e)
		{
		}

		void _CurrentGame_Draw(object sender, DrawEventArgs e)
		{
			// zastavime hru
			StopGame();

			// zapiseme to do historie
			AddDrawToHistory();

			RefreshMoveControls();
			RefreshReplay();

			_Document.Changed();

			// oznamime
			System.Windows.Forms.MessageBox.Show("Dolo k remze. " + e.Reason, ProductName,
				System.Windows.Forms.MessageBoxButtons.OK, System.Windows.Forms.MessageBoxIcon.Information);
		}

		/// <summary>
		/// Potaov hr zv a ppadn pod nabdku k remze.
		/// </summary>
		/// <param name="player">Hr, kter m podn zvit.</param>
		/// <returns>Vrt hodnotu urujc, zda k remze skuten dolo.</returns>
		protected bool DecideForDraw(Player player)
		{
			if(player.Type != PlayerType.Computer)
			{
				// dolo k chyb v synchronizaci s pemlecm procesem
				Debug.Fail("Zadno rozhodovn o remze pro lidskho hre.");
				return false;
			}

			// pokud chtel remizu,
			if(ComputerPlayer.ShouldOfferDraw(Game, player.Color))
			{
				// nabidne ji
				return Game.OfferDraw(player);
			}

			return false;
		}

		/// <summary>
		/// Obnov v UI monosti remzy.
		/// </summary>
		protected void RefreshDrawOptions()
		{
			Player clovek = null, pocitac = null;

			// pokud hra nebezi, konec
			if(Game == null || !Game.Running)
			{
				drawRequestLabel.Text = string.Empty;
				acceptDrawLinkLabel.Visible = false;
				drawToolStripButton.Enabled = drawToolStripMenuItem.Enabled = false;
				return;
			}

			// zjistime druhy hracu
			if(Game.Player1.Type == PlayerType.Human)
				clovek = Game.Player1;
			else if(Game.Player2.Type == PlayerType.Human)
				clovek = Game.Player2;

			if(Game.Player1.Type == PlayerType.Computer)
				pocitac = Game.Player1;
			else if(Game.Player2.Type == PlayerType.Computer)
				pocitac = Game.Player2;

			// pokud nehraje clovek s pocitacem, konec
			if(clovek == null || pocitac == null)
			{
				drawRequestLabel.Text = string.Empty;
				acceptDrawLinkLabel.Visible = false;
				// hraji-li dva lide,
				if(clovek != null)
					// povolime remizu, byl-li uz proveden nejaky tah
					drawToolStripButton.Enabled = drawToolStripMenuItem.Enabled = Game.CurrentMoveNumber > 1;
				else
					// jinak ne
					drawToolStripButton.Enabled = drawToolStripMenuItem.Enabled = false;
				return;
			}

			MoveInfo[] historie = Game.GetHistory();
			// zjistime moznosti
			bool protihrac_nabizi = pocitac == Game.Player1 ? Game.Player1DrawOffer : Game.Player2DrawOffer;
			bool mame_pravo = historie.Length > 0 && (historie[historie.Length - 1].CanDrawByFiftyMoveRule ||
				historie[historie.Length - 1].CanDrawByThreefoldRepetition);
			// pokud je moznost remizy,
			if(Game.PlayerOnMove.Type == PlayerType.Human && (protihrac_nabizi || mame_pravo))
			{
				// zobrazime
				if(mame_pravo)
					drawRequestLabel.Text = "Mte prvo na remzu.";
				else
					drawRequestLabel.Text = "Protihr nabz remzu.";
				acceptDrawLinkLabel.Visible = true;
				drawToolStripButton.Enabled = drawToolStripMenuItem.Enabled = true;
			}
			else
			{
				// jinak nechame zmizet
				drawRequestLabel.Text = string.Empty;
				acceptDrawLinkLabel.Visible = false;
				drawToolStripButton.Enabled = drawToolStripMenuItem.Enabled = false;
			}
		}
	}
}