﻿using System;
using System.Collections.Generic;
using System.Text;

namespace Střelci
{
	/// <summary>
	/// Představuje střelce.
	/// </summary>
	public class Bishop : Piece
	{
		/// <summary>
		/// Vytvoří nového střelce na zadané šachovnici.
		/// </summary>
		/// <param name="chessboard">Šachovnice, na kterou bude střelec umístěn.</param>
		/// <param name="position">Pozice na šachovnici, kde bude střelec umístěn.</param>
		/// <param name="color">Barva střelce.</param>
		/// <exception cref="OutOfChessboardException">Nastane, když je zadané políčko mimo šachovnici.</exception>
		/// <exception cref="InvalidOperationException">Nastane, když je zadané políčko již obsazeno.</exception>
		public Bishop(Chessboard chessboard, Position position, PieceColor color)
			: base(chessboard, position, color)
		{
			
		}

		/// <summary>
		/// Vytvoří stejného střelce na jiné šachovnici.
		/// </summary>
		/// <param name="chessboard">Šachovnice, na které bude umístěn nový střelec.</param>
		/// <param name="original">Vzor figurky.</param>
		/// <exception cref="ArgumentNullException">Není zadána šachovnice nebo figurka.</exception>
		public Bishop(Chessboard chessboard, Bishop original) : base(chessboard, original)
		{
		}

		/// <summary>
		/// Vrátí textové označení figurky.
		/// </summary>
		public override string ToString()
		{
			return (Color == PieceColor.Black ? "Černý" : "Bílý") + " střelec na " + Position;
		}
	}
}
