﻿using System;
using System.Collections.Generic;
using System.Text;

namespace Střelci
{
	/// <summary>
	/// Představuje krále.
	/// </summary>
	public class King : Piece
	{
		/// <summary>
		/// Vytvoří nového krále na zadané šachovnici.
		/// </summary>
		/// <param name="chessboard">Šachovnice, na kterou bude král umístěn.</param>
		/// <param name="position">Pozice na šachovnici, kde bude král umístěn.</param>
		/// <param name="color">Barva krále.</param>
		/// <exception cref="OutOfChessboardException">Nastane, když je zadané políčko mimo šachovnici.</exception>
		/// <exception cref="InvalidOperationException">Nastane, když je zadané políčko již obsazeno, 
		/// nebo pokud král dané barvy již na šachovnici je.</exception>
		public King(Chessboard chessboard, Position position, PieceColor color)
			: base(chessboard, position, color)
		{
			
		}

		/// <summary>
		/// Vytvoří stejného krále na jiné šachovnici.
		/// </summary>
		/// <param name="chessboard">Šachovnice, na které bude umístěn nový král.</param>
		/// <param name="original">Vzor figurky.</param>
		/// <exception cref="ArgumentNullException">Není zadána šachovnice nebo figurka.</exception>
		public King(Chessboard chessboard, King original) : base(chessboard, original)
		{
		}

		/// <summary>
		/// Vrátí textové označení figurky.
		/// </summary>
		public override string ToString()
		{
			return (Color == PieceColor.Black ? "Černý" : "Bílý") + " král na " + Position;
		}
	}
}
