﻿using System;
using System.Collections.Generic;
using System.Diagnostics;
using System.Text;

namespace Střelci
{
	/// <summary>
	/// Představuje pěšce.
	/// </summary>
	public class Pawn : Piece
	{
		/// <summary>
		/// Vytvoří nového pěšce na zadané šachovnici.
		/// </summary>
		/// <param name="chessboard">Šachovnice, na kterou bude pěšec umístěn.</param>
		/// <param name="position">Pozice na šachovnici, kde bude pěšec umístěn.</param>
		/// <param name="color">Barva figurky.</param>
		/// <exception cref="ArgumentNullException">Není zadána šachovnice.</exception>
		/// <exception cref="OutOfChessboardException">Nastane, když je zadané políčko mimo šachovnici.</exception>
		/// <exception cref="InvalidOperationException">Nastane, když je zadané políčko již obsazeno.</exception>
		public Pawn(Chessboard chessboard, Position position, PieceColor color)
			: base(chessboard, position, color)
		{
		}

		/// <summary>
		/// Vytvoří stejného pěšce na jiné šachovnici.
		/// </summary>
		/// <param name="chessboard">Šachovnice, na které bude umístěn nový pěšec.</param>
		/// <param name="original">Vzor figurky.</param>
		/// <exception cref="ArgumentNullException">Není zadána šachovnice nebo figurka.</exception>
		public Pawn(Chessboard chessboard, Pawn original) : base(chessboard, original)
		{
		}

		/// <summary>
		/// Vrátí textové označení figurky.
		/// </summary>
		public override string ToString()
		{
			return (Color == PieceColor.Black ? "Černý" : "Bílý") + " pěšec na " + Position;
		}
	}
}
