﻿using System;
using System.Collections.Generic;
using System.Text;

namespace Střelci
{
	/// <summary>
	/// Představuje dámu.
	/// </summary>
	public class Queen : Piece
	{
		/// <summary>
		/// Vytvoří novou dámu na zadané šachovnici.
		/// </summary>
		/// <param name="chessboard">Šachovnice, na kterou bude dámu umístěna.</param>
		/// <param name="position">Pozice na šachovnici, kde bude dámu umístěna.</param>
		/// <param name="color">Barva dámy.</param>
		/// <exception cref="OutOfChessboardException">Nastane, když je zadané políčko mimo šachovnici.</exception>
		/// <exception cref="InvalidOperationException">Nastane, když je zadané políčko již obsazeno.</exception>
		public Queen(Chessboard chessboard, Position position, PieceColor color)
			: base(chessboard, position, color)
		{
			
		}

		/// <summary>
		/// Vytvoří stejnou dámu na jiné šachovnici.
		/// </summary>
		/// <param name="chessboard">Šachovnice, na které bude umístěna nová dámu.</param>
		/// <param name="original">Vzor dámy.</param>
		/// <exception cref="ArgumentNullException">Není zadána šachovnice nebo figurka.</exception>
		public Queen(Chessboard chessboard, Queen original) : base(chessboard, original)
		{
		}

		/// <summary>
		/// Vrátí textové označení figurky.
		/// </summary>
		public override string ToString()
		{
			return (Color == PieceColor.Black ? "Černá" : "Bílá") + " dáma na " + Position;
		}
	}
}
