﻿using System;
using System.Collections.Generic;
using System.Diagnostics;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using Střelci.Properties;

namespace Střelci
{
	/// <summary>
	/// Představuje bránu, která nechává vykreslovat hru a zpracovává uživatelský vstup.
	/// </summary>
	abstract class Gate : IDisposable
	{
		private Painter _Painter;

		/// <summary>
		/// Malíř, který se používá k vykreslování šachovnice.
		/// </summary>
		public Painter Painter
		{
			get { return _Painter; }
		}

		/// <summary>
		/// Vytvoří novou bránu pro partii.
		/// </summary>
		/// <param name="game">Partie, která bude vykreslována a ovládána.</param>
		/// <param name="painter">Malíř, který se bude používat k vykreslování šachovnice</param>
		/// <exception cref="ArgumentNullException">Některý z parametrů je null.</exception>
		public Gate(Painter painter)
		{
			// stejne tak budeme chtit malire
			if(painter == null) throw new ArgumentNullException("painter");

			// zapamatujeme si hodnoty
			_Painter = painter;

			// zavesime se na zajimave udalosti
			painter.OutputControl.MouseClick += new MouseEventHandler(m_OutputControl_MouseClick);
		}

		protected abstract void m_OutputControl_MouseClick(object sender, MouseEventArgs e);

		#region Technické detaily - úklid

		private bool Disposed = false;

		public void Dispose()
		{
			// zabranime GC uvolnit nas podruhe
			GC.SuppressFinalize(this);
			// uklid
			Dispose(true);
		}

		~Gate()
		{
			// uklid
			Dispose(false);
		}

		protected virtual void Dispose(bool disposeManaged)
		{
			if(!Disposed)
			{
				// uklid rizenych prostredku
				if(disposeManaged)
				{
					_Painter.OutputControl.MouseClick -= new MouseEventHandler(m_OutputControl_MouseClick);
				}
				Disposed = true;
			}
		}

		#endregion
	}
}
