﻿using System;
using System.Collections.Generic;
using System.Text;

namespace Střelci
{
	/// <summary>
	/// Obsahuje statistiku přemýšlení počítačového hráče.
	/// </summary>
	class ThinkingCounter : IEnumerable<KeyValuePair<string, int>>
	{
		Dictionary<string, int> _Counters = new Dictionary<string, int>();
		static ThinkingCounter _Me;

		protected ThinkingCounter()
		{
		}

		public int this[string counterName]
		{
			get
			{
				int hodnota;
				lock(this)
				{
					if(_Counters.TryGetValue(counterName, out hodnota))
						return hodnota;
					else
						return 0;
				}
			}
			set
			{
				lock(this)
				{
					if(_Counters.ContainsKey(counterName))
						_Counters[counterName] = value;
					else
						_Counters.Add(counterName, value);
				}
			}
		}

		public void Reset()
		{
			_Counters.Clear();
		}

		public static ThinkingCounter Instance
		{
			get
			{
				if(_Me == null)
					return _Me = new ThinkingCounter();
				else
					return _Me;
			}
		}


		#region IEnumerable<KeyValuePair<string,int>> Members

		public IEnumerator<KeyValuePair<string, int>> GetEnumerator()
		{
			return _Counters.GetEnumerator();
		}

		#endregion

		#region IEnumerable Members

		System.Collections.IEnumerator System.Collections.IEnumerable.GetEnumerator()
		{
			return _Counters.GetEnumerator();
		}

		#endregion
		}
}
