﻿using System;
using System.Collections.Generic;
using System.Text;
using System.Diagnostics;

namespace Střelci
{
	/// <summary>
	/// Představuje generátor tahů.
	/// </summary>
	public static class Generator
	{
		///// <summary>
		///// Vrátí pole všech možných tahů dané figurky.
		///// </summary>
		///// <param name="piece">Figurka, jejíž tahy se budou generovat.</param>
		///// <param name="game">Partie, ve které se budou tahy odehrávat.</param>
		///// <param name="onlyThreaten">True, má-li se generovat pouze ohrožování tímto tahem.</param>
		//public static Move[] GeneratePossibleMoves(Piece piece, Chessboard chessboard, Game game,
		//    bool onlyThreaten, bool onlyCapturing)
		//{
		//    // vygenerujeme
		//    LinkedList<Move> seznam = GeneratePossibleMovesList(piece, game, onlyThreaten,
		//        onlyCapturing, null);

		//    // vytvorime pole pro vysledek
		//    Move[] pole = new Move[seznam.Count];
		//    // zkopirujeme do pole tahy
		//    seznam.CopyTo(pole, 0);
		//    // vratime ho
		//    return pole;
		//}

		/// <summary>
		/// Představuje funkci filtru, která bude vracet, zda zadaný tah zahrnout do vygenerovaných.
		/// </summary>
		/// <param name="game">Partie, ve které se tah odehrává.</param>
		/// <param name="move">Tah, který se provede.</param>
		/// <returns>True, má-li se tah zahrnout.</returns>
		public delegate bool MoveFilter(Game game, Move move);

		/// <summary>
		/// Představuje filtr, který zahrne všechny tahy.
		/// </summary>
		/// <param name="game">Partie, ve které se tah odehrává.</param>
		/// <param name="move">Tah, který se provede.</param>
		public static bool AllMovesFilter(Game game, Move move)
		{
			return true;
		}

		/// <summary>
		/// Vrátí pole všech možných tahů figurek zadané barvy na šachovnici.
		/// </summary>
		/// <remarks>
		/// Používá zadanou šachovnici, nikoliv tu, která je součástí partie.
		/// </remarks>
		/// <param name="chessboard">Šachovnice, pro jejíž figurky se tahy budou generovat.</param>
		/// <param name="game">Partie, ve které se budou tahy odehrávat.</param>
		/// <param name="onlyThreaten">True, má-li se generovat pouze ohrožování tímto tahem.</param>
		/// <param name="color">Barva, pro kterou se budou figurky generovat. Je-li null, 
		/// generuje se pro obě barvy.</param>
		public static Move[] GeneratePossibleMoves(Chessboard chessboard, Game game,
			PieceColor? color, MoveFilter moveFilter)
		{
			LinkedList<Move>[] pole = new LinkedList<Move>[chessboard.PieceCount];
			int i = 0;
			int pocet = 0;

			//Debug.WriteLine("Generování možných tahů pro šachovnici " + chessboard.GetHashCode() + " a hráče " + color);

			ThinkingCounter.Instance["Generator.GeneratePossibleMoves"]++;

			// projdeme figurky
			foreach(Piece figurka in chessboard)
			{
				Debug.Assert(figurka.Chessboard == chessboard, "Figurka se nachází na jiné šachovnici než je zadaná.");

				// pripadne preskocime
				if(color != null && color.Value != figurka.Color)
					continue;

				// vygenerujeme tahy pro figurku a umistime do pole
				pole[i] = GeneratePossibleMovesList(figurka, game, moveFilter);
				pocet += pole[i].Count;
				i++;
			}
			
			// vytvorime pole pro vysledek
			Move[] navrat = new Move[pocet];
			// zkopirujeme tahy do pole
			i = 0;
			foreach(LinkedList<Move> jedny in pole)
			{
				if(jedny != null)
				{
					jedny.CopyTo(navrat, i);
					i += jedny.Count;
				}
			}
			// vratime
			return navrat;
		}

		/// <summary>
		/// Vrátí seznam všech možných tahů dané figurky.
		/// </summary>
		private static LinkedList<Move> GeneratePossibleMovesList(Piece piece, Game game, MoveFilter moveFilter)
		{
			LinkedList<Move> seznam = new LinkedList<Move>();
			RelativePosition[] mozne = Judge.GetPiecePossibleDraws(piece.GetType());

			ThinkingCounter.Instance["Generator.GeneratePossibleMovesList"]++;

			// projdeme vsechny mozne cilove pozice
			foreach(RelativePosition rp in mozne)
			{
				// vytvorime tah
				Move tah = new Move(piece, rp);

				// pokud tah projde filtrem, pridame ho do seznamu
				if(moveFilter(game, tah))
					seznam.AddLast(tah);
			}

			// vratime
			return seznam;
		}
	}
}
