﻿using System;
using System.Collections.Generic;
using System.Windows.Forms;
using System.Diagnostics;

namespace Střelci
{
	static class Program
	{
		/// <summary>
		/// Hlavní vstupní bod aplikace.
		/// </summary>
		[STAThread]
		static void Main()
		{
			// zavesime se na neosetrenou chybu
			Application.ThreadException += new System.Threading.ThreadExceptionEventHandler(Application_ThreadException);

			Application.EnableVisualStyles();
			Application.SetCompatibleTextRenderingDefault(false);

			// spustime
			Application.Run(new ChessForm());
		}

		/// <summary>
		/// Vrátí název souboru nápovědy.
		/// </summary>
		public static string GetHelpFileName()
		{
			return System.IO.Path.Combine(
				System.IO.Path.GetDirectoryName(Application.ExecutablePath),
				@"Nápověda\střelci.chm");
		}

		static void Application_ThreadException(object sender, System.Threading.ThreadExceptionEventArgs e)
		{
			try
			{
				// pro jistotu
				//Application.DoEvents();

				//Debugger.Break();

				using(ErrorForm frm = new ErrorForm(e.Exception))
				{
					// zobrazime okno s chybou
					DialogResult dr = frm.ShowDialog();

					// bud skoncime, nebo v tichosti pokracujem
					if(dr == DialogResult.Abort)
					{
						// sebevrazda
						Environment.FailFast(string.Format("Aplikace {0} ukončena po vzniku " +
							"neošetřené výjimky typu {1}. {2}",
							Application.ProductName, e.Exception.GetType().Name, e.Exception.Message));
					}
					// pokracujem...
				}
			}
			catch(Exception ex)
			{
				Debug.Fail("Výjimka při zpracování výjimky: " + ex.Message);
				// chyba v chybe, to je blbe...
				MessageBox.Show("V bloku zachycení neošetřených výjimek došlo k výjimce. " + ex.Message,
					Application.ProductName, MessageBoxButtons.OK, MessageBoxIcon.Error);
			}
		}
	}
}