﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using Střelci.Properties;

namespace Střelci
{
	/// <summary>
	/// Představuje okno nastavení aplikace.
	/// </summary>
	public partial class SettingsForm : Form
	{
		/// <summary>
		/// Vytvoří nové okno nastavení aplikace.
		/// </summary>
		public SettingsForm()
		{
			InitializeComponent();

			// nacteme nastaveni
			LoadSettings();
		}

		private void saveButton_Click(object sender, EventArgs e)
		{
			// ulozime
			SaveSettings();
			// a zavreme se
			this.DialogResult = DialogResult.OK;
		}

		/// <summary>
		/// Načte nastavení do ovládacích prvků.
		/// </summary>
		protected void LoadSettings()
		{
			// cteme
			useSoundsCheckBox.Checked = Settings.Default.PlaySounds;
			highQualityDrawingCheckBox.Checked = Settings.Default.HighQualityDrawing;
			showHistoryCheckBox.Checked = Settings.Default.ShowHistory;
			if(Settings.Default.OneButtonControl)
				oneButtonControlRadioButton.Checked = true;
			else
				twoButtonControlRadioButton.Checked = true;
		}

		/// <summary>
		/// Uloží nastavení z ovládacích prvků.
		/// </summary>
		protected void SaveSettings()
		{
			// ulozime
			Settings.Default.PlaySounds = useSoundsCheckBox.Checked;
			Settings.Default.OneButtonControl = oneButtonControlRadioButton.Checked;
			Settings.Default.HighQualityDrawing = highQualityDrawingCheckBox.Checked;
			Settings.Default.ShowHistory = showHistoryCheckBox.Checked;

			Settings.Default.Save();
		}

		/// <summary>
		/// Obnoví původní hodnoty nastavení.
		/// </summary>
		protected static void ResetSettings()
		{
			// zresetujeme
			Settings.Default.Reset();
		}

		private void defaultSettingsButton_Click(object sender, EventArgs e)
		{
			// pro jistotu se zeptame
			DialogResult dr = MessageBox.Show("Chcete opravdu nastavení obnovit do výchozích hodnot?",
				ProductName, MessageBoxButtons.YesNo, MessageBoxIcon.Question, MessageBoxDefaultButton.Button2);

			if(dr == DialogResult.Yes)
			{
				// obnovime
				ResetSettings();
				// a zavreme se
				this.DialogResult = DialogResult.OK; 
			}
		}

		
	}
}